@@ -201,11 +201,13 @@ func TestCountCharacters_Transform(t *testing.T) {
 			name: "Normal String",
 			args: args{data: []byte("the quick brown fox jumps over a lazy dog")},
 			want: "41",
-		}, {
+		},
+		{
 			name: "Emoji",
 			args: args{data: []byte("😃😇🙃🙂😉😌😙😗🇮🇳")},
 			want: "10",
-		}, {
+		},
+		{
 			name: "Multi line string",
 			args: args{data: []byte("123345\nabcd\n456\n123\nabc\n567\n7890")},
 			want: "32",
@@ -393,7 +395,7 @@ func TestKebab_Command(t *testing.T) {
 		name        string
 		title       string
 	}{
-		//alias:       []string{"b64-enc", "b64-encode"},
+		// alias:       []string{"b64-enc", "b64-encode"},
 		description: "Transform your text to kebab-case",
 		filterValue: "To Kebab case (kebab)",
 		flags:       nil,
@@ -710,7 +712,7 @@ func TestCamel_Command(t *testing.T) {
 		title       string
 	}{
 		alias:       nil,
-		description: "Transform your text to CamelCase",
+		description: "Transform your text to camelCase",
 		filterValue: "To Camel case (camel)",
 		flags:       nil,
 		name:        "camel",
@@ -738,6 +740,100 @@ func TestCamel_Command(t *testing.T) {
 }
 
 func TestStringToCamel(t *testing.T) {
+	type args struct {
+		data []byte
+		in1  []Flag
+	}
+	tests := []struct {
+		name    string
+		args    args
+		want    string
+		wantErr bool
+	}{
+		{
+			name: "Normal String",
+			args: args{data: []byte("the quick brown fox jumps over a lazy dog")},
+			want: "theQuickBrownFoxJumpsOverALazyDog",
+		},
+		{
+			name: "String Uppercase",
+			args: args{data: []byte("THE QUICK BROWN FOX JUMPS OVER A LAZY DOG")},
+			want: "theQuickBrownFoxJumpsOverALazyDog",
+		},
+		{
+			name: "Camel Case Text",
+			args: args{data: []byte("camelCaseText")},
+			want: "camelCaseText", // stable
+		},
+		{
+			name: "Pascal Case Text",
+			args: args{data: []byte("PascalCaseText")},
+			want: "pascalCaseText",
+		},
+		{
+			name: "Underscore text lowercase",
+			args: args{data: []byte("underscore_text")},
+			want: "underscoreText",
+		},
+		{
+			name: "Underscore text uppercase",
+			args: args{data: []byte("UNDERSCORE_TEXT_UPPER_CASE")},
+			want: "underscoreTextUpperCase",
+		},
+	}
+	for _, tt := range tests {
+		t.Run(tt.name, func(t *testing.T) {
+			p := Camel{}
+			got, err := p.Transform(tt.args.data, tt.args.in1...)
+			if (err != nil) != tt.wantErr {
+				t.Errorf("Transform() error = %v, wantErr %v", err, tt.wantErr)
+				return
+			}
+			if got != tt.want {
+				t.Errorf("Transform() got = %v, want %v", got, tt.want)
+			}
+		})
+	}
+}
+
+func TestPascal_Command(t *testing.T) {
+	test := struct {
+		alias       []string
+		description string
+		filterValue string
+		flags       []Flag
+		name        string
+		title       string
+	}{
+		alias:       nil,
+		description: "Transform your text to PascalCase",
+		filterValue: "To Pascal case (pascal)",
+		flags:       nil,
+		name:        "pascal",
+		title:       "To Pascal case (pascal)",
+	}
+	p := Pascal{}
+	if got := p.Alias(); !reflect.DeepEqual(got, test.alias) {
+		t.Errorf("Alias() = %v, want %v", got, test.alias)
+	}
+	if got := p.Description(); got != test.description {
+		t.Errorf("Description() = %v, want %v", got, test.description)
+	}
+	if got := p.FilterValue(); got != test.filterValue {
+		t.Errorf("FilterValue() = %v, want %v", got, test.filterValue)
+	}
+	if got := p.Flags(); !reflect.DeepEqual(got, test.flags) {
+		t.Errorf("Flags() = %v, want %v", got, test.flags)
+	}
+	if got := p.Name(); got != test.name {
+		t.Errorf("Name() = %v, want %v", got, test.name)
+	}
+	if got := p.Title(); got != test.title {
+		t.Errorf("Title() = %v, want %v", got, test.title)
+	}
+}
+
+func TestStringToPascal(t *testing.T) {
 	type args struct {
 		data []byte
 		in1  []Flag
@@ -752,7 +848,8 @@ func TestStringToCamel(t *testing.T) {
 			name: "Normal String",
 			args: args{data: []byte("the quick brown fox jumps over a lazy dog")},
 			want: "TheQuickBrownFoxJumpsOverALazyDog",
-		}, {
+		},
+		{
 			name: "String Uppercase",
 			args: args{data: []byte("THE QUICK BROWN FOX JUMPS OVER A LAZY DOG")},
 			want: "TheQuickBrownFoxJumpsOverALazyDog",
@@ -762,6 +859,11 @@ func TestStringToCamel(t *testing.T) {
 			args: args{data: []byte("camelCaseText")},
 			want: "CamelCaseText",
 		},
+		{
+			name: "Pacal Case Text",
+			args: args{data: []byte("PacalCaseText")},
+			want: "PacalCaseText", // stable
+		},
 		{
 			name: "Underscore text lowercase",
 			args: args{data: []byte("underscore_text")},
@@ -775,7 +877,7 @@ func TestStringToCamel(t *testing.T) {
 	}
 	for _, tt := range tests {
 		t.Run(tt.name, func(t *testing.T) {
-			p := Camel{}
+			p := Pascal{}
 			got, err := p.Transform(tt.args.data, tt.args.in1...)
 			if (err != nil) != tt.wantErr {
 				t.Errorf("Transform() error = %v, wantErr %v", err, tt.wantErr)
